@@ -72,11 +72,11 @@
 
 排序使用 `pyim-dregcache-iword2count' 中记录的词频信息"
   (sort words-list
-        #'(lambda (a b)
-            (let ((a (car (split-string a ":")))
-                  (b (car (split-string b ":"))))
-              (> (or (gethash a pyim-dregcache-iword2count) 0)
-                 (or (gethash b pyim-dregcache-iword2count) 0))))))
+        (lambda (a b)
+          (let ((a (car (split-string a ":")))
+                (b (car (split-string b ":"))))
+            (> (or (gethash a pyim-dregcache-iword2count) 0)
+               (or (gethash b pyim-dregcache-iword2count) 0))))))
 
 (defun pyim-dregcache-sort-icode2word ()
   "对个人词库排序."
@@ -84,18 +84,18 @@
   (with-temp-buffer
     (dolist (l (split-string pyim-dregcache-icode2word "\n"))
       (cond
-        ((string-match "^\\([a-z-]+ \\)\\(.*\\)" l)
-         ;; 3字以上词很少，如果只处理单字,2字词,3字词
-         ;; ((string-match "^\\([a-z]+ \\|[a-z]+-[a-z]+ \\|[a-z]+-[a-z]+-[a-z]+ \\)\\(.*\\)" l)
-         (let* ((pinyin (match-string 1 l))
-                (words (pyim-dregcache-sort-words (split-string (match-string 2 l) " "))))
-           (insert (format "%s\n" (concat pinyin (mapconcat #'identity words " "))))))
-        ;; 其他词
-        ((string= l "")
-         ;; skip empty line
-         )
-        (t
-         (insert (format "%s\n" l)))))
+       ((string-match "^\\([a-z-]+ \\)\\(.*\\)" l)
+        ;; 3字以上词很少，如果只处理单字,2字词,3字词
+        ;; ((string-match "^\\([a-z]+ \\|[a-z]+-[a-z]+ \\|[a-z]+-[a-z]+-[a-z]+ \\)\\(.*\\)" l)
+        (let* ((pinyin (match-string 1 l))
+               (words (pyim-dregcache-sort-words (split-string (match-string 2 l) " "))))
+          (insert (format "%s\n" (concat pinyin (mapconcat #'identity words " "))))))
+       ;; 其他词
+       ((string= l "")
+        ;; skip empty line
+        )
+       (t
+        (insert (format "%s\n" l)))))
     (setq pyim-dregcache-icode2word (buffer-string))))
 
 (defun pyim-dregcache-create-cache-content (raw-content)
@@ -256,18 +256,16 @@ DICT-FILES 是词库文件列表. DICTS-MD5 是词库的MD5校验码.
       (setq word (match-string-no-properties 1 content))
       (when word
         (cond
-          ((string-match "^[^ ]+$" word)
-           ;; 单个词
-           (push word output))
-          (t
-           ;; 多个字
-           (setq output (append (nreverse (split-string word " +")) output)))))
+         ((string-match "^[^ ]+$" word)
+          ;; 单个词
+          (push word output))
+         (t
+          ;; 多个字
+          (setq output (append (nreverse (split-string word " +")) output)))))
       ;; 继续搜索
       (setq start (+ start 2 (length code) (length word))))
     output))
 
-(declare-function pyim-pinyin2cchar-get "pyim" (pinyin &optional equal-match return-list include-seperator))
-
 (defun pyim-dregcache-get (code &optional from)
   "从 `pyim-dregcache-cache' 搜索 CODE, 得到对应的词条."
   (if (or (memq 'icode2word from)
@@ -284,7 +282,7 @@ DICT-FILES 是词库文件列表. DICTS-MD5 是词库的MD5校验码.
       ;; `push' plus `nreverse' is more efficient than `add-to-list'
       ;; Many examples exist in Emacs' own code
       (setq result (nreverse result))
-      `(,@result ,@(pyim-pinyin2cchar-get code t t)))))
+      `(,@result ,@(pyim-pymap-py2cchar-get code t t)))))
 
 (defun pyim-dregcache-get-icode2word-ishortcode2word (code)
   "以 CODE 搜索个人词和个人联想词.  正则表达式搜索词库,不需要为联想词开单独缓存."
@@ -376,17 +374,17 @@ DICT-FILES 是词库文件列表. DICTS-MD5 是词库的MD5校验码.
     (let* ((case-fold-search t)
            substring beg end)
       (while (re-search-forward (concat "^\\([a-z-]+\\) \\(.*\\)" word "\\(.*\\)$") nil t)
-          (setq beg (match-beginning 0))
-          (setq end (match-end 0))
-          (setq substring (concat (match-string-no-properties 1)
-                                  (match-string-no-properties 2)
-                                  (match-string-no-properties 3)))
+        (setq beg (match-beginning 0))
+        (setq end (match-end 0))
+        (setq substring (concat (match-string-no-properties 1)
+                                (match-string-no-properties 2)
+                                (match-string-no-properties 3)))
 
-          ;; delete string and the newline char
-          (delete-region beg (+ 1 end))
-          (when (> (length (split-string substring " ")) 1)
-            (goto-char beg)
-            (insert substring)))
+        ;; delete string and the newline char
+        (delete-region beg (+ 1 end))
+        (when (> (length (split-string substring " ")) 1)
+          (goto-char beg)
+          (insert substring)))
       (setq pyim-dregcache-icode2word
             (buffer-string))))
   ;; 删除对应词条的词频
@@ -418,13 +416,20 @@ DICT-FILES 是词库文件列表. DICTS-MD5 是词库的MD5校验码.
       (goto-char (or beg (point-max)))
       (insert replace-string))
     (setq pyim-dregcache-icode2word
-            (buffer-string))))
+          (buffer-string))))
+
+(defun pyim-dregcache-upgrade-icode2word ()
+  "升级 icode2word 缓存。
+
+dregcache 只支持全拼和双拼，不能用于五笔之类的型码输入法，而
+update-icode2word 目前只要是用于更新型码输入法的 code-prefix, 所
+以不需要具体实现细节。")
 
 (defun pyim-dregcache-search-word-code-1 (word content)
-    (let* ((case-fold-search t)
-           (regexp (concat "^\\([a-z-]+\\)\\(.*\\) " "\\(" word " \\|" word "$\\)")))
-      (when (string-match regexp content)
-        (match-string-no-properties 1 content))))
+  (let* ((case-fold-search t)
+         (regexp (concat "^\\([a-z-]+\\)\\(.*\\) " "\\(" word " \\|" word "$\\)")))
+    (when (string-match regexp content)
+      (match-string-no-properties 1 content))))
 
 (defun pyim-dregcache-search-word-code (word)
   "从 `pyim-dregcache-cache' 和 `pyim-dregcache-icode2word' 搜索 word, 得到对应的code."
