@@ -92,8 +92,8 @@
        ;; isearch 启动的时候，会设置一个 buffer variable: `isearch-mode'
        ;; 检测所有 buffer 中 `isearch-mode' 的取值，如果任何一个
        ;; 取值为 t, 就说明 isearch 已经启动。
-       (cl-some #'(lambda (buf)
-                    (buffer-local-value 'isearch-mode buf))
+       (cl-some (lambda (buf)
+                  (buffer-local-value 'isearch-mode buf))
                 (buffer-list))))
 
 (defun pyim-probe-org-structure-template ()
@@ -122,7 +122,7 @@
                 (cl-search non-digit-str-before-1 "0123456789"))
       (cl-incf offset)
       (setq non-digit-str-before-1 (pyim-char-before-to-string offset)))
-    (unless (string= (buffer-name) " *temp*") ; Make sure this probe can work with exim of exwm.
+    (unless (pyim-exwm-enable-p)
       (if (<= (point) (save-excursion (back-to-indentation)
                                       (point)))
           (not (or (pyim-string-match-p
@@ -146,7 +146,7 @@
 这个函数用于：`pyim-english-input-switch-functions' 。"
   (let ((str-before-1 (pyim-char-before-to-string 0))
         (str-before-2 (pyim-char-before-to-string 1)))
-    (unless (string= (buffer-name) " *temp*")
+    (unless (pyim-exwm-enable-p)
       (if (> (point) (save-excursion (back-to-indentation)
                                      (point)))
           (or (if (pyim-string-match-p " " str-before-1)
@@ -168,13 +168,12 @@
 
 用于：`pyim-punctuation-half-width-functions' 。"
   (let ((line-string (buffer-substring (point-at-bol) (point))))
-    (unless (string= (buffer-name) " *temp*") ; Make sure this probe can work with exim of exwm.
+    (unless (pyim-exwm-enable-p)
       (and (member (char-to-string char)
                    (mapcar #'car pyim-punctuation-dict))
            (string-match "^[ \t]*$" line-string)))))
 
-(declare-function pyim-char-before-to-string "pyim" (num))
-(declare-function pyim-entered-get "pyim" (&optional type))
+(declare-function pyim-entered-get "pyim-entered" (&optional type))
 (declare-function org-inside-LaTeX-fragment-p "org")
 (declare-function org-inside-latex-macro-p "org")
 
